@@ -9,7 +9,7 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 
 sub error
@@ -694,13 +694,6 @@ Display the text chunk given as an argument on C<STDOUT>.
 This is a convenience function for debugging rather than a
 general-purpose routine.
 
-=head1 SUPPORT
-
-There is L<a mailing list for this Perl module at Google
-Groups|https://groups.google.com/forum/#!forum/perlimagepng>. If you
-have an enquiry, post to the mailing list. You don't have to join the
-mailing list to post a message.
-
 =head1 SEE ALSO
 
 =head2 In this distribution
@@ -794,29 +787,6 @@ The book "PNG - The Definitive Guide" by Greg Roelofs, published in
 1999 by O'Reilly is available online at
 L<http://www.faqs.org/docs/png/>. 
 
-=head1 EXAMPLES
-
-There is a collection of demonstrations and example scripts online at
-L<http://www.lemoda.net/image-png/>. This currently contains
-
-=over
-
-=item PNG inspector L<http://www.lemoda.net/png/inspect/>
-
-This demonstration downloads a PNG file you specify from the internet
-and prints out its contents.
-
-=item PNG quantizer L<http://www.lemoda.net/png/quantize/>
-
-This demonstration downloads a PNG file you specify from the internet
-and quantizes it with as many colours as you want (from two to 256) in
-order to reduce its size. The quantized image is uploaded to imgur.com
-using L<WWW::Imgur>.
-
-=back
-
-
-
 =head1 AUTHOR
 
 Ben Bullock, <bkb@cpan.org>
@@ -824,25 +794,12 @@ Ben Bullock, <bkb@cpan.org>
 =head1 COPYRIGHT & LICENCE
 
 The Image::PNG package and associated files are copyright (C)
-2014 Ben Bullock.
+2015 Ben Bullock.
 
 You can use, copy, modify and redistribute Image::PNG and
 associated files under the Perl Artistic Licence or the GNU General
 Public Licence.
 
-=head1 SUPPORT
-
-=head2 Mailing list
-
-There is a mailing list at
-L<http://groups.google.com/group/perlimagepng>. It is not necessary to
-be a member of the list to post messages to the list or participate in
-discussions.
-
-=head2 CPAN stuff
-
-There is a bug tracker at L<https://github.com/benkasminbullock/Image-PNG/issues>.
-
 =head1 FOR PROGRAMMERS
 
 The distributed files are not the source code of the module. The
